/*
  A summary of a stream in the system, as provided by the `p4 streams` command.

*/
function StreamsCommand(data) {

    Object.defineProperties(this, {
        /*
          Specifies the stream's name (permanent identifier) and its path in the stream depot, in the form `//depotname/streamname`.

        */
        "stream": {
            value: data ? data.stream : undefined,
            enumerable: true,
            writable: true
        },
        /*
          The date the stream specification was last modified.

        */
        "update": {
            enumerable: true,
            get: function() {
                if (data && data.update) {
                    var strVal = data.update;
                    return Date.parse(strVal);
                }
            }
        },
        /*
          The date and time that the stream specification was last accessed by any Perforce command.

        */
        "access": {
            enumerable: true,
            get: function() {
                if (data && data.access) {
                    var strVal = data.access;
                    return Date.parse(strVal);
                }
            }
        },
        /*
          The Perforce user or group who owns the stream.
          The default is the user who created the stream.

        */
        "owner": {
            value: data ? data.owner : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Display name of the stream.
          Unlike the Stream: field, this field can be modified.
          Defaults to the streamname portion of the stream path.

        */
        "name": {
            value: data ? data.name : undefined,
            enumerable: true,
            writable: true
        },
        /*
          The parent of this stream.
          Must be none if the stream's `Type:` is mainline, otherwise must be set to an existing stream identifier of the form `//depotname/streamname`.

        */
        "parent": {
            value: data ? data.parent : undefined,
            enumerable: true,
            writable: true
        },
        /*
          The stream’s type determines the expected flow of change.
          Valid stream types are `mainline`, `virtual`, `development`, and `release`.

          - `mainline`:
          The mainline stream is the parent of all streams in the stream depot. Every stream depot must have at least one mainline stream.

          - `virtual`:
          Virtual streams allow merging and copying between parent and child streams without storing local data.
          Data is passed through to the destination (a non-virtual stream) after applying restrictions on the scope of files defined in the virtual stream’s view.
          Because virtual streams do not have files in their depot namespace, it is impossible to import a virtual stream.

          - `release`:
          More stable than the mainline.
          Release streams copy from the parent and merge to the parent.

          - `development`:
          Less stable than the mainline.
          Development streams expect to merge from parent streams and copy to the parent.

          - `task`:
          Task streams are lightweight short-lived branches that are useful for bug fixing or new features that only modify a small subset of the branch data.
          Because branched (copied) files are tracked in a set of shadow tables which are later removed, repository metadata is kept to a minimum when using this type of stream.
          Workspaces associated with task streams see all branched data, but only modified and promoted data is visible to users with access to the stream’s namespace.
          The default is stream type is development.

        */
        "type": {
            value: data ? data.type : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Description of the stream.

        */
        "description": {
            value: data ? data.description : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Settings that configure stream behavior as follows:

          - `[un]locked`:
          Enable/disable other users' ability to edit or delete the stream.
          If locked, the stream specification cannot be deleted, and only its owner can modify it.
          The default is unlocked.

          - `[all|owner]submit`:
          Specifies whether all users or only the owner of the stream can submit changes to the stream.
          The default is allsubmit.
          If the Owner: of a stream marked ownersubmit is a group, all users who are members of that group can submit changes to the stream.

          - `[no]toparent`:
          Specifies whether integrations from the stream to its parent are expected.
          The default is toparent.

          - `[no]fromparent`:
          Specifies whether integrations to the stream from its parent are expected.
          The default is fromparent for mainline and development streams, and nofromparent for release streams.

          - `mergeany | mergedown`:
          Specifies whether the merge flow is restricted or whether merge is permitted from any other stream.
          For example, the mergeany option would allow a merge from a child to a parent with no warnings.
          A virtual stream must have its flow options set to notoparent and nofromparent.
          Flow options are ignored for mainline streams.

        */
        "options": {
            value: data ? data.options : undefined,
            enumerable: true,
            writable: true
        }
    });

}

module.exports = StreamsCommand;
